@@ -1,28 +1,18 @@
 import hashlib
 from django import forms
+from mptt.forms import TreeNodeChoiceField
+from mptt.admin import MPTTAdminForm
 from ccpages.models import Page
 
 
-class PageAdminForm(forms.ModelForm):
-
-    def __init__(self, *args, **kwargs):
-        super(PageAdminForm, self).__init__(*args, **kwargs)
-        # TODO: is there a better way to prevent the TreeNodeChoiceField
-        # form widget displaying invalid moves?
-        if self.instance.pk is not None:
-            self.fields['parent'].queryset = self.fields['parent'].queryset\
-                    .exclude(
-                            pk__in=[self.instance.pk]
-                    ).exclude(
-                            pk__in=[d.pk for d in self.instance.get_children()]
-                    )
+class PageAdminForm(MPTTAdminForm):
 
     class Meta:
         model = Page
 
     class Media:
         css = {
-                'screen': ('ccpages/admin.css',)
+                'screen': ('ccpages/css/admin.css',)
             }
 
 class PagePasswordForm(forms.Form):
