@@ -4,6 +4,18 @@ from ccpages.models import Page
 
 register = template.Library()
 
+@register.inclusion_tag('ccpages/_js.html')
+def ccpages_js():
+    return {
+        'STATIC_URL': settings.STATIC_URL,
+    }
+
+@register.inclusion_tag('ccpages/_css.html')
+def ccpages_css():
+    return {
+        'STATIC_URL': settings.STATIC_URL,
+    }
+
 @register.inclusion_tag('ccpages/_nav_breadcrumb.html')
 def ccpages_nav_breadcrumbs(page):
     """returns a breadcrumb"""
